#ifndef NT2_INCLUDE_FUNCTIONS_NEGIF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NEGIF_HPP_INCLUDED

#include <nt2/boolean/include/functions/negif.hpp>

#endif
